@@ -1,23 +1,10 @@
 /*
- * TagLibExtractor tests.
- *
- * Copyright (C) 2015  Juan Palacios <jpalaciosdev@gmail.com>
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
- *
- */
+    TagLibExtractor tests.
+
+    SPDX-FileCopyrightText: 2015 Juan Palacios <jpalaciosdev@gmail.com>
+
+    SPDX-License-Identifier: LGPL-2.1-or-later
+*/
 
 #include "taglibextractortest.h"
 #include "simpleextractionresult.h"
@@ -46,6 +33,18 @@ const QStringList TagLibExtractorTest::propertyEnumNames(const QList<KFileMetaDa
     return result;
 }
 
+void TagLibExtractorTest::testNoExtraction()
+{
+    TagLibExtractor plugin{this};
+
+    SimpleExtractionResult result(testFilePath("test.opus"), QStringLiteral("audio/opus"), ExtractionResult::ExtractNothing);
+    plugin.extract(&result);
+
+    QCOMPARE(result.types().size(), 1);
+    QCOMPARE(result.types().constFirst(), Type::Audio);
+    QCOMPARE(result.properties().size(), 0);
+}
+
 void TagLibExtractorTest::testPropertyTypes()
 {
     TagLibExtractor plugin{this};
@@ -377,6 +376,34 @@ void TagLibExtractorTest::testMp4_data()
         ;
 }
 
+void TagLibExtractorTest::testAax()
+{
+    QFETCH(QString, fileType);
+
+    QString fileName = testFilePath(QStringLiteral("nocoverage_test.") + fileType);
+    QString mimeType = QStringLiteral("audio/vnd.audible.aax");
+
+    TagLibExtractor plugin{this};
+    SimpleExtractionResult resultAax(fileName, mimeType);
+    plugin.extract(&resultAax);
+
+    QCOMPARE(resultAax.properties().value(Property::AlbumArtist), QVariant(QStringLiteral("Album Artist")));
+    QCOMPARE(resultAax.properties().value(Property::Artist), QVariant(QStringLiteral("Artist")));
+    QCOMPARE(resultAax.properties().value(Property::Genre), QVariant(QStringLiteral("Hörbuch")));
+    QCOMPARE(resultAax.properties().value(Property::Copyright), QVariant(QStringLiteral("CopyrightHolder")));
+    QCOMPARE(resultAax.properties().value(Property::Title), QVariant(QStringLiteral("TrackTitle")));
+    QCOMPARE(resultAax.properties().value(Property::Channels).toInt(), 2);
+}
+
+void TagLibExtractorTest::testAax_data()
+{
+    QTest::addColumn<QString>("fileType");
+
+    QTest::addRow("aax")
+        << QStringLiteral("aax")
+        ;
+}
+
 void TagLibExtractorTest::testAsf()
 {
     QFETCH(QString, fileType);
@@ -565,6 +592,12 @@ void TagLibExtractorTest::testNoMetadata_data()
             << expectedKeys << QString()
                ;
 
+    QTest::addRow("aax")
+            << QFINDTESTDATA("samplefiles/no-meta/test.aax")
+            << QStringLiteral("audio/vnd.audible.aax")
+            << expectedKeys << QString()
+               ;
+
 }
 
 void  TagLibExtractorTest::testNoMetadata()
@@ -581,8 +614,17 @@ void  TagLibExtractorTest::testNoMetadata()
     const auto resultList = extracted.properties();
     const auto resultKeys = resultList.uniqueKeys();
 
-    const auto excessKeys = resultKeys.toSet() - expectedKeys.toSet();
-    const auto missingKeys = expectedKeys.toSet() - resultKeys.toSet();
+#if QT_VERSION < QT_VERSION_CHECK(5, 14, 0)
+    const QSet<KFileMetaData::Property::Property> resultKeySet = resultKeys.toSet();
+    const QSet<KFileMetaData::Property::Property> expectedKeySet = expectedKeys.toSet();
+#else
+    const QSet<KFileMetaData::Property::Property> resultKeySet(resultKeys.begin(), resultKeys.end());
+    const QSet<KFileMetaData::Property::Property> expectedKeySet(expectedKeys.begin(), expectedKeys.end());
+#endif
+
+    const auto excessKeys = resultKeySet - expectedKeySet;
+    const auto missingKeys = expectedKeySet - resultKeySet;
+
     if (!excessKeys.isEmpty()) {
         const auto propNames =  propertyEnumNames(excessKeys.values()).join(QLatin1String(", "));
         if (failMessage.isEmpty()) {
@@ -598,7 +640,6 @@ void  TagLibExtractorTest::testNoMetadata()
     }
     QCOMPARE(resultKeys, expectedKeys);
     if (!failMessage.isEmpty()) {
-        auto excessKeys = resultKeys.toSet() - expectedKeys.toSet();
         const auto message = QStringLiteral("%1: %2")
                 .arg(failMessage)
                 .arg(propertyEnumNames(excessKeys.values()).join(QLatin1String(", ")));
